diff -urN upstream.orig/bfd/ChangeLog-0001 upstream/bfd/ChangeLog-0001
--- upstream.orig/bfd/ChangeLog-0001	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/ChangeLog-0001	2011-05-25 23:42:44.226514794 +0200
@@ -8159,21 +8159,21 @@
 
 2000-05-22  Momchil Velikov  <velco@fadata.bg>
 
-	* libbfd.c (_bfd_generic_verify_endian_match): Compare endianess
+	* libbfd.c (_bfd_generic_verify_endian_match): Compare endianness
 	only if it is known for both input and output bfds. Separate
 	error message strings as in some languages, it may be necessary
 	to change more than one place in the string to change between
 	'big' and 'little'.
 
 	* elf32-ppc.c (ppc_elf_merge_private_bfd_data): Remove inline
-	endianess checks, call _bfd_generic_verify_endian_match() instead.
+	endianness checks, call _bfd_generic_verify_endian_match() instead.
 
 	* elf32-mips.c (_bfd_mips_elf_merge_private_bfd_data): Likewise.
 
 	* elf32-mcore.c (mcore_elf_merge_private_bfd_data): Likewise.
 
 	* elf32-arm.h (elf32_arm_merge_private_bfd_data): Likewise. Verify
-	endianess before checking bfd flavours.
+	endianness before checking bfd flavours.
 
 2000-05-22  H.J. Lu  <hjl@gnu.org>
 
diff -urN upstream.orig/bfd/ChangeLog-9193 upstream/bfd/ChangeLog-9193
--- upstream.orig/bfd/ChangeLog-9193	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/ChangeLog-9193	2011-05-25 23:42:44.462511223 +0200
@@ -1563,7 +1563,7 @@
 	* coff-alpha.c (alpha_ecoff_backend_data): Removed initialization
 	of big_magic and little_magic.
 	* coff-mips.c (mips_ecoff_bad_format_hook): Make sure magic number
-	matches endianess of bfd.
+	matches endianness of bfd.
 	(mips_ecoff_backend_data): Removed initialization of big_magic and
 	little_magic.
 	* ecoff.c (ecoff_set_arch_mach_hook): Set MIPS machine number
@@ -6085,7 +6085,7 @@
 	* configure.in:  fix vax ultrix configuration.
 
 	* elf.c (bfd_section_from_shdr):  Deal with null return from
-	bfd_make_section().  (elf_object_p):  Select endianess properly.
+	bfd_make_section().  (elf_object_p):  Select endianness properly.
 
 Fri Jan 31 01:19:55 1992  John Gilmore  (gnu at cygnus.com)
 
@@ -6994,7 +6994,7 @@
 	setup the environment.
 
 	* archive.c: (bfd_slurp_coff_armap) coff archives always have the
-	headers in big endian format, regardless of the endianess of the
+	headers in big endian format, regardless of the endianness of the
 	host or target.
 
 	* archures.c: totally changed. Now an architecture is represented
diff -urN upstream.orig/bfd/coff-mcore.c upstream/bfd/coff-mcore.c
--- upstream.orig/bfd/coff-mcore.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/coff-mcore.c	2011-05-25 23:42:44.106516609 +0200
@@ -377,7 +377,7 @@
   if (info->relocatable)
     return TRUE;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (   input_bfd->xvec->byteorder != output_bfd->xvec->byteorder
       && output_bfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN)
     {
diff -urN upstream.orig/bfd/coff-stgo32.c upstream/bfd/coff-stgo32.c
--- upstream.orig/bfd/coff-stgo32.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/coff-stgo32.c	2011-05-25 23:42:44.622508802 +0200
@@ -102,7 +102,7 @@
 
 #include "coff-i386.c"
 
-/* This macro is used, because I cannot assume the endianess of the
+/* This macro is used, because I cannot assume the endianness of the
    host system.  */
 #define _H(index) (H_GET_16 (abfd, (header+index*2)))
 
diff -urN upstream.orig/bfd/elf32-arm.c upstream/bfd/elf32-arm.c
--- upstream.orig/bfd/elf32-arm.c	2011-05-19 10:39:28.000000000 +0200
+++ upstream/bfd/elf32-arm.c	2011-05-25 23:42:43.998518245 +0200
@@ -10220,7 +10220,7 @@
 		    - relocation;
 		  addend += msec->output_section->vma + msec->output_offset;
 
-		  /* Cases here must match those in the preceeding
+		  /* Cases here must match those in the preceding
 		     switch statement.  */
 		  switch (r_type)
 		    {
@@ -15431,7 +15431,7 @@
   bfd_boolean flags_compatible = TRUE;
   asection *sec;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.orig/bfd/elf32-m68hc1x.c upstream/bfd/elf32-m68hc1x.c
--- upstream.orig/bfd/elf32-m68hc1x.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/elf32-m68hc1x.c	2011-05-25 23:42:44.122516367 +0200
@@ -1188,7 +1188,7 @@
   flagword new_flags;
   bfd_boolean ok = TRUE;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (!_bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.orig/bfd/elf32-mcore.c upstream/bfd/elf32-mcore.c
--- upstream.orig/bfd/elf32-mcore.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/elf32-mcore.c	2011-05-25 23:42:44.630508681 +0200
@@ -55,7 +55,7 @@
   flagword old_flags;
   flagword new_flags;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.orig/bfd/elf32-mep.c upstream/bfd/elf32-mep.c
--- upstream.orig/bfd/elf32-mep.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/elf32-mep.c	2011-05-25 23:42:43.698522784 +0200
@@ -606,7 +606,7 @@
   flagword old_flags, new_flags;
   flagword old_partial, new_partial;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (_bfd_generic_verify_endian_match (ibfd, obfd) == FALSE)
     return FALSE;
 
diff -urN upstream.orig/bfd/elf32-mt.c upstream/bfd/elf32-mt.c
--- upstream.orig/bfd/elf32-mt.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/elf32-mt.c	2011-05-25 23:42:44.470511101 +0200
@@ -521,7 +521,7 @@
   flagword     old_flags, new_flags;
   bfd_boolean  ok = TRUE;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (_bfd_generic_verify_endian_match (ibfd, obfd) == FALSE)
     return FALSE;
 
diff -urN upstream.orig/bfd/elf32-ppc.c upstream/bfd/elf32-ppc.c
--- upstream.orig/bfd/elf32-ppc.c	2011-05-23 14:49:10.000000000 +0200
+++ upstream/bfd/elf32-ppc.c	2011-05-25 23:42:44.098516731 +0200
@@ -4145,7 +4145,7 @@
   if (!is_ppc_elf (ibfd) || !is_ppc_elf (obfd))
     return TRUE;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.orig/bfd/elf32-xtensa.c upstream/bfd/elf32-xtensa.c
--- upstream.orig/bfd/elf32-xtensa.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/elf32-xtensa.c	2011-05-25 23:42:44.374512553 +0200
@@ -3466,7 +3466,7 @@
   unsigned out_mach, in_mach;
   flagword out_flag, in_flag;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (!_bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
diff -urN upstream.orig/bfd/elf64-ppc.c upstream/bfd/elf64-ppc.c
--- upstream.orig/bfd/elf64-ppc.c	2011-05-23 14:49:10.000000000 +0200
+++ upstream/bfd/elf64-ppc.c	2011-05-25 23:42:43.822520907 +0200
@@ -2733,7 +2733,7 @@
 static bfd_boolean
 ppc64_elf_merge_private_bfd_data (bfd *ibfd, bfd *obfd)
 {
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (ibfd->xvec->byteorder != obfd->xvec->byteorder
       && ibfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN
       && obfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN)
diff -urN upstream.orig/bfd/elfxx-mips.c upstream/bfd/elfxx-mips.c
--- upstream.orig/bfd/elfxx-mips.c	2011-05-24 00:43:05.000000000 +0200
+++ upstream/bfd/elfxx-mips.c	2011-05-25 23:42:44.614508922 +0200
@@ -12538,7 +12538,7 @@
   bfd_boolean null_input_bfd = TRUE;
   asection *sec;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     {
       (*_bfd_error_handler)
diff -urN upstream.orig/bfd/netbsd.h upstream/bfd/netbsd.h
--- upstream.orig/bfd/netbsd.h	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/netbsd.h	2011-05-25 23:42:43.654523449 +0200
@@ -108,7 +108,7 @@
   /* The NetBSD magic number is always big-endian */
 #ifndef TARGET_IS_BIG_ENDIAN_P
   /* XXX aren't there any macro to change byteorder of a word independent of
-     the host's or target's endianesses?  */
+     the host's or target's endiannesses?  */
   execp->a_info
     = (execp->a_info & 0xff) << 24 | (execp->a_info & 0xff00) << 8
       | (execp->a_info & 0xff0000) >> 8 | (execp->a_info & 0xff000000) >> 24;
diff -urN upstream.orig/bfd/nlmcode.h upstream/bfd/nlmcode.h
--- upstream.orig/bfd/nlmcode.h	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/nlmcode.h	2011-05-25 23:42:44.250514430 +0200
@@ -491,7 +491,7 @@
 		  NLM_SIGNATURE_SIZE) != 0)
     goto got_wrong_format_error;
 
-  /* There's no supported way to discover the endianess of an NLM, so test for
+  /* There's no supported way to discover the endianness of an NLM, so test for
      a sane version number after doing byte swapping appropriate for this
      XVEC.  (Hack alert!)  */
   if (i_fxdhdrp->version > 0xFFFF)
diff -urN upstream.orig/bfd/vms-alpha.c upstream/bfd/vms-alpha.c
--- upstream.orig/bfd/vms-alpha.c	2011-05-07 16:39:59.000000000 +0200
+++ upstream/bfd/vms-alpha.c	2011-05-25 23:41:13.195892703 +0200
@@ -440,7 +440,7 @@
 {
   struct bfd_link_hash_table root;
 
-  /* Vector of shared libaries.  */
+  /* Vector of shared libraries.  */
   struct vector_type shrlibs;
 
   /* Fixup section.  */
diff -urN upstream.orig/binutils/ChangeLog-2007 upstream/binutils/ChangeLog-2007
--- upstream.orig/binutils/ChangeLog-2007	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/ChangeLog-2007	2011-05-25 23:42:44.642508498 +0200
@@ -687,7 +687,7 @@
 	* resres.c: Likewise.
 	* resrc.c: Likewise. Dumps as RC are now recompilable.
 	* windres.c: As above. Using bfd for res and provide target
-	specific endianess support.
+	specific endianness support.
 	* windres.h: Use windint.h as include. Additionally removed K&R
 	syntax.
 	* winduni.c: New printing and unichar support routines.
diff -urN upstream.orig/binutils/ChangeLog-2008 upstream/binutils/ChangeLog-2008
--- upstream.orig/binutils/ChangeLog-2008	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/ChangeLog-2008	2011-05-25 23:42:44.690507773 +0200
@@ -840,8 +840,8 @@
 	PR binutils/55326
 	* bucomm.c (list_supported_architectures): Free architecture list
 	after use.
-	* windres.c (set_endianess): Likewise.
-	* windmc.c (set_endianess): Likewise.
+	* windres.c (set_endianness): Likewise.
+	* windmc.c (set_endianness): Likewise.
 
 2008-01-08  Kai Tietz  <kai.tietz@onevision.com>
 
diff -urN upstream.orig/binutils/ChangeLog-2009 upstream/binutils/ChangeLog-2009
--- upstream.orig/binutils/ChangeLog-2009	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/ChangeLog-2009	2011-05-25 23:42:44.718507349 +0200
@@ -128,8 +128,8 @@
 
 2009-11-16  Kai Tietz  <kai.tietz@onevision.com>
 
-	* windmc.c (set_endianess): Use bfd_get_target_info.
-	* windres.c (set_endianess): Likewise.
+	* windmc.c (set_endianness): Use bfd_get_target_info.
+	* windres.c (set_endianness): Likewise.
 	(find_arch_match): Removed.
 
 2009-11-11  Nick Clifton  <nickc@redhat.com>
@@ -1122,7 +1122,7 @@
 
 2009-02-09  Kai Tietz  <kai.tietz@onevision.com>
 
-	* windres.c (set_endianess): Copy name without leading '-'.
+	* windres.c (set_endianness): Copy name without leading '-'.
 
 2009-02-09  Tristan Gingold  <gingold@adacore.com>
 
@@ -1339,7 +1339,7 @@
 
 2009-01-06  Kai Tietz  <kai.tietz@onevision.com>
 
-	* windres.c (set_endianess): Get architecture name
+	* windres.c (set_endianness): Get architecture name
 	for internal target names like "pe-arm-wince-little".
 	(find_arch_match): New helper.
 	* ChangeLog: Reset it.
diff -urN upstream.orig/binutils/NEWS upstream/binutils/NEWS
--- upstream.orig/binutils/NEWS	2011-05-01 16:27:53.000000000 +0200
+++ upstream/binutils/NEWS	2011-05-25 23:42:45.618493730 +0200
@@ -116,7 +116,7 @@
 
 * Add codepage support to the windres tool.  It now supports many new
   resource types (e.g. MANIFEST, TOOLBAR, etc).  The output generation
-  for binary files is done now via bfd itself.  The endianess problems
+  for binary files is done now via bfd itself.  The endianness problems
   for different hosts are solved.  Dumps of .res files can now be
   re-compiled by windres without lossing resources or compilation errors.
   Some problems on dialog resource translations are corrected.
diff -urN upstream.orig/binutils/po/bg.po upstream/binutils/po/bg.po
--- upstream.orig/binutils/po/bg.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/bg.po	2011-05-25 23:42:44.946503899 +0200
@@ -6694,7 +6694,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/po/binutils.pot upstream/binutils/po/binutils.pot
--- upstream.orig/binutils/po/binutils.pot	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/binutils.pot	2011-05-25 23:42:45.018502810 +0200
@@ -6791,7 +6791,7 @@
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header "
 "file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/po/da.po upstream/binutils/po/da.po
--- upstream.orig/binutils/po/da.po	2011-04-27 14:09:50.000000000 +0200
+++ upstream/binutils/po/da.po	2011-05-25 23:42:44.794506199 +0200
@@ -7012,7 +7012,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/po/es.po upstream/binutils/po/es.po
--- upstream.orig/binutils/po/es.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/es.po	2011-05-25 23:42:45.182500327 +0200
@@ -7248,7 +7248,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/po/fi.po upstream/binutils/po/fi.po
--- upstream.orig/binutils/po/fi.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/fi.po	2011-05-25 23:42:45.098501598 +0200
@@ -7375,7 +7375,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/po/fr.po upstream/binutils/po/fr.po
--- upstream.orig/binutils/po/fr.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/fr.po	2011-05-25 23:42:44.874504988 +0200
@@ -7145,7 +7145,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
@@ -7165,7 +7165,7 @@
 "  -C --codepage_in=<val>       Choisi le codepage lors de la lecture du fichier texte mc\n"
 "  -d --decimal_values          Affiche les valeurs du fichier texte en décimal\n"
 "  -e --extension=<extension>   Choisi l'extension de l'en-tête utilisée pour exporter l'en-tête du fichier\n"
-"  -F --target <cible>          Spécifie l'ordre des octets (endianess) de la sortie.\n"
+"  -F --target <cible>          Spécifie l'ordre des octets (endianness) de la sortie.\n"
 "  -h --headerdir=<répertoire>  Choisi le répertoire pour exporter les en-têtes\n"
 "  -u --unicode_in              Lit le fichier d'entrée en UTF16\n"
 "  -U --unicode_out             Écrit les messages binaires en UFT16\n"
diff -urN upstream.orig/binutils/po/id.po upstream/binutils/po/id.po
--- upstream.orig/binutils/po/id.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/id.po	2011-05-25 23:42:45.250499298 +0200
@@ -6244,7 +6244,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/po/ja.po upstream/binutils/po/ja.po
--- upstream.orig/binutils/po/ja.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/ja.po	2011-05-25 23:42:45.550494759 +0200
@@ -7143,7 +7143,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
@@ -7163,7 +7163,7 @@
 "  -C --codepage_in=<val>       mc テキストファイル読み込み時にコードページを設定する\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/po/ru.po upstream/binutils/po/ru.po
--- upstream.orig/binutils/po/ru.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/ru.po	2011-05-25 23:42:45.394497118 +0200
@@ -7230,7 +7230,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
@@ -7250,7 +7250,7 @@
 "  -C --codepage_in=<знач>      установить кодировку при чтении текстового mc-файла\n"
 "  -d --decimal_values          вывести значения в текстовый файл в десятичном виде\n"
 "  -e --extension=<расширение>  установить расширение для заголовка, используемое в файле экспорта заголовка\n"
-"  -F --target <цель>           указать выходную цель для endianess.\n"
+"  -F --target <цель>           указать выходную цель для endianness.\n"
 "  -h --headerdir=<каталог>     установить каталог для экспорта заголовков\n"
 "  -u --unicode_in              читать входной файл как файл UTF16\n"
 "  -U --unicode_out             записывать двоичные сообщения в формате UFT16\n"
diff -urN upstream.orig/binutils/po/sk.po upstream/binutils/po/sk.po
--- upstream.orig/binutils/po/sk.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/sk.po	2011-05-25 23:42:45.318498270 +0200
@@ -6037,7 +6037,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/po/uk.po upstream/binutils/po/uk.po
--- upstream.orig/binutils/po/uk.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/uk.po	2011-05-25 23:42:45.610493851 +0200
@@ -5617,7 +5617,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
@@ -5637,7 +5637,7 @@
 "  -C --codepage_in=<значення>  Встановити кодову сторінку при читанні текстового файлу mc\n"
 "  -d --decimal_values          Виводити значення у текстовий файл у десятковому форматі\n"
 "  -e --extension=<розширення>  Встановити розширення заголовку, що використовувалось при експорті файлу заголовку\n"
-"  -F --target <target>         Вказує ціль виводу для endianess.\n"
+"  -F --target <target>         Вказує ціль виводу для endianness.\n"
 "  -h --headerdir=<каталог>     Встановити каталог експорту для заголовків\n"
 "  -u --unicode_in              Кодування вхідного файлу UTF16\n"
 "  -U --unicode_out             Кодування файлу виводу UFT16\n"
diff -urN upstream.orig/binutils/po/vi.po upstream/binutils/po/vi.po
--- upstream.orig/binutils/po/vi.po	2011-04-19 10:03:32.000000000 +0200
+++ upstream/binutils/po/vi.po	2011-05-25 23:42:45.466496030 +0200
@@ -6410,7 +6410,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
diff -urN upstream.orig/binutils/readelf.c upstream/binutils/readelf.c
--- upstream.orig/binutils/readelf.c	2011-05-01 16:27:53.000000000 +0200
+++ upstream/binutils/readelf.c	2011-05-25 23:42:27.550767158 +0200
@@ -1852,7 +1852,7 @@
     case EM_MMA:		return "Fujitsu Multimedia Accelerator";
     case EM_PCP:		return "Siemens PCP";
     case EM_NCPU:		return "Sony nCPU embedded RISC processor";
-    case EM_NDR1:		return "Denso NDR1 microprocesspr";
+    case EM_NDR1:		return "Denso NDR1 microprocessor";
     case EM_STARCORE:		return "Motorola Star*Core processor";
     case EM_ME16:		return "Toyota ME16 processor";
     case EM_ST100:		return "STMicroelectronics ST100 processor";
diff -urN upstream.orig/binutils/resres.c upstream/binutils/resres.c
--- upstream.orig/binutils/resres.c	2011-04-19 10:03:33.000000000 +0200
+++ upstream/binutils/resres.c	2011-05-25 23:42:44.682507893 +0200
@@ -98,7 +98,7 @@
   off = 0;
 
   if (! probe_binary (&wrbfd, flen))
-    set_windres_bfd_endianess (&wrbfd, ! target_is_bigendian);
+    set_windres_bfd_endianness (&wrbfd, ! target_is_bigendian);
 
   skip_null_resource (&wrbfd, &off, flen);
 
diff -urN upstream.orig/binutils/windint.h upstream/binutils/windint.h
--- upstream.orig/binutils/windint.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream/binutils/windint.h	2011-05-25 23:42:44.702507590 +0200
@@ -1083,6 +1083,6 @@
 extern rc_uint_type windres_get_32 (windres_bfd *, const void *, rc_uint_type);
 
 extern void set_windres_bfd (windres_bfd *, bfd *, asection *, rc_uint_type);
-extern void set_windres_bfd_endianess (windres_bfd *, int);
+extern void set_windres_bfd_endianness (windres_bfd *, int);
 
 #endif
diff -urN upstream.orig/binutils/windmc.c upstream/binutils/windmc.c
--- upstream.orig/binutils/windmc.c	2011-04-19 10:03:33.000000000 +0200
+++ upstream/binutils/windmc.c	2011-05-25 23:42:44.674508014 +0200
@@ -205,7 +205,7 @@
   -C --codepage_in=<val>       Set codepage when reading mc text file\n\
   -d --decimal_values          Print values to text files decimal\n\
   -e --extension=<extension>   Set header extension used on export header file\n\
-  -F --target <target>         Specify output target for endianess.\n\
+  -F --target <target>         Specify output target for endianness.\n\
   -h --headerdir=<directory>   Set the export directory for headers\n\
   -u --unicode_in              Read input file as UTF16 file\n\
   -U --unicode_out             Write binary messages as UFT16\n\
@@ -231,7 +231,7 @@
 }
 
 static void
-set_endianess (bfd *abfd, const char *target)
+set_endianness (bfd *abfd, const char *target)
 {
   const bfd_target *target_vec;
 
@@ -239,7 +239,7 @@
   target_vec = bfd_get_target_info (target, abfd, &target_is_bigendian, NULL,
 				   &def_target_arch);
   if (! target_vec)
-    fatal ("Can't detect target endianess and architecture.");
+    fatal ("Can't detect target endianness and architecture.");
   if (! def_target_arch)
     fatal ("Can't detect architecture.");
 }
@@ -1054,7 +1054,7 @@
       ++optind;
     }
 
-  set_endianess (NULL, target);
+  set_endianness (NULL, target);
 
   if (input_filename == NULL)
     {
diff -urN upstream.orig/binutils/windres.c upstream/binutils/windres.c
--- upstream.orig/binutils/windres.c	2011-04-19 10:03:33.000000000 +0200
+++ upstream/binutils/windres.c	2011-05-25 23:42:44.658508257 +0200
@@ -54,7 +54,7 @@
 int target_is_bigendian = 0;
 const char *def_target_arch;
 
-static void set_endianess (bfd *, const char *);
+static void set_endianness (bfd *, const char *);
 
 /* An enumeration of format types.  */
 
@@ -1049,7 +1049,7 @@
 	output_format = format_from_filename (output_filename, 0);
     }
 
-  set_endianess (NULL, target);
+  set_endianness (NULL, target);
 
   /* Read the input file.  */
   switch (input_format)
@@ -1098,7 +1098,7 @@
 }
 
 static void
-set_endianess (bfd *abfd, const char *target)
+set_endianness (bfd *abfd, const char *target)
 {
   const bfd_target *target_vec;
 
@@ -1106,7 +1106,7 @@
   target_vec = bfd_get_target_info (target, abfd, &target_is_bigendian, NULL,
                                    &def_target_arch);
   if (! target_vec)
-    fatal ("Can't detect target endianess and architecture.");
+    fatal ("Can't detect target endianness and architecture.");
   if (! def_target_arch)
     fatal ("Can't detect architecture.");
 }
@@ -1127,7 +1127,7 @@
 }
 
 void
-set_windres_bfd_endianess (windres_bfd *wrbfd, int is_bigendian)
+set_windres_bfd_endianness (windres_bfd *wrbfd, int is_bigendian)
 {
   assert (!! wrbfd);
   switch (WR_KIND(wrbfd))
diff -urN upstream.orig/gas/as.c upstream/gas/as.c
--- upstream.orig/gas/as.c	2011-04-19 10:03:33.000000000 +0200
+++ upstream/gas/as.c	2011-05-25 23:39:44.345238311 +0200
@@ -461,7 +461,7 @@
   static const struct option std_longopts[] =
   {
     /* Note: commas are placed at the start of the line rather than
-       the end of the preceeding line so that it is simpler to
+       the end of the preceding line so that it is simpler to
        selectively add and remove lines from this list.  */
     {"alternate", no_argument, NULL, OPTION_ALTERNATE}
     /* The entry for "a" is here to prevent getopt_long_only() from
diff -urN upstream.orig/gas/config/tc-ppc.c upstream/gas/config/tc-ppc.c
--- upstream.orig/gas/config/tc-ppc.c	2011-05-19 10:39:28.000000000 +0200
+++ upstream/gas/config/tc-ppc.c	2011-05-25 23:42:45.686492701 +0200
@@ -1153,7 +1153,7 @@
       else if (strcmp (arg, "emb") == 0)
 	ppc_flags |= EF_PPC_EMB;
 
-      /* -mlittle/-mbig set the endianess.  */
+      /* -mlittle/-mbig set the endianness.  */
       else if (strcmp (arg, "little") == 0
 	       || strcmp (arg, "little-endian") == 0)
 	{
diff -urN upstream.orig/gas/po/es.po upstream/gas/po/es.po
--- upstream.orig/gas/po/es.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/gas/po/es.po	2011-05-25 23:39:43.793246673 +0200
@@ -16666,7 +16666,7 @@
 
 #: read.c:2949
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr "se encontr� .end%c sin un %s precedente"
 
 #: read.c:2979 read.c:3009
@@ -18432,7 +18432,7 @@
 #~ msgid "inlining literal pool; specify location with .literal_position."
 #~ msgstr "conjunto de literales inlining; especificar la ubicaci�n con .literal_position."
 
-#~ msgid ".endr encountered without preceeding .rept, .irc, or .irp"
+#~ msgid ".endr encountered without preceding .rept, .irc, or .irp"
 #~ msgstr "se encontr� una directiva .endr sin una directiva .rept, .irc, � .irp precedente"
 
 #~ msgid "subsegment index too high"
diff -urN upstream.orig/gas/po/fi.po upstream/gas/po/fi.po
--- upstream.orig/gas/po/fi.po	2011-05-18 10:18:03.000000000 +0200
+++ upstream/gas/po/fi.po	2011-05-25 23:39:43.597249643 +0200
@@ -16676,7 +16676,7 @@
 
 #: read.c:2949
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ".end%c kohdattu ilman edeltävää %s"
 
 #: read.c:2979 read.c:3009
diff -urN upstream.orig/gas/po/fr.po upstream/gas/po/fr.po
--- upstream.orig/gas/po/fr.po	2011-05-18 10:18:03.000000000 +0200
+++ upstream/gas/po/fr.po	2011-05-25 23:39:43.221255339 +0200
@@ -16661,7 +16661,7 @@
 
 #: read.c:2949
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ".end%c n'est pas précédé de %s"
 
 #: read.c:2979 read.c:3009
diff -urN upstream.orig/gas/po/gas.pot upstream/gas/po/gas.pot
--- upstream.orig/gas/po/gas.pot	2011-04-19 10:03:33.000000000 +0200
+++ upstream/gas/po/gas.pot	2011-05-25 23:39:43.413252431 +0200
@@ -16312,7 +16312,7 @@
 
 #: read.c:2949
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ""
 
 #: read.c:2979 read.c:3009
diff -urN upstream.orig/gas/po/id.po upstream/gas/po/id.po
--- upstream.orig/gas/po/id.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/gas/po/id.po	2011-05-25 23:39:43.969244007 +0200
@@ -16057,7 +16057,7 @@
 
 #: read.c:2939
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ".end%c ditemui tanpa diawali %s"
 
 #: read.c:2969
diff -urN upstream.orig/gas/po/ru.po upstream/gas/po/ru.po
--- upstream.orig/gas/po/ru.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/gas/po/ru.po	2011-05-25 23:39:44.137241463 +0200
@@ -15638,7 +15638,7 @@
 
 #: read.c:2939
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ""
 
 #: read.c:2969
diff -urN upstream.orig/gas/po/rw.po upstream/gas/po/rw.po
--- upstream.orig/gas/po/rw.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/gas/po/rw.po	2011-05-25 23:39:43.021258369 +0200
@@ -13588,7 +13588,7 @@
 
 #: read.c:2897
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ""
 
 #: read.c:2927
diff -urN upstream.orig/gas/po/tr.po upstream/gas/po/tr.po
--- upstream.orig/gas/po/tr.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/gas/po/tr.po	2011-05-25 23:39:44.329238555 +0200
@@ -14321,7 +14321,7 @@
 
 #: read.c:2897
 #, fuzzy, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr "öncesinde .%s olmayan .end%s"
 
 #: read.c:2927
@@ -15789,7 +15789,7 @@
 #~ msgid "operand %s0x%x out of range"
 #~ msgstr "%s0x%x işleneni kapsam dışı"
 
-#~ msgid ".endr encountered without preceeding .rept, .irc, or .irp"
+#~ msgid ".endr encountered without preceding .rept, .irc, or .irp"
 #~ msgstr "öncesinde .rept, .irc veya .irp olmaksızın .endr"
 
 #~ msgid "subsegment index too high"
diff -urN upstream.orig/gas/read.c upstream/gas/read.c
--- upstream.orig/gas/read.c	2011-05-07 16:39:59.000000000 +0200
+++ upstream/gas/read.c	2011-05-25 23:39:42.857260853 +0200
@@ -2935,7 +2935,7 @@
 static void
 s_bad_end (int endr)
 {
-  as_warn (_(".end%c encountered without preceeding %s"),
+  as_warn (_(".end%c encountered without preceding %s"),
 	   endr ? 'r' : 'm',
 	   endr ? ".rept, .irp, or .irpc" : ".macro");
   demand_empty_rest_of_line ();
diff -urN upstream.orig/gold/dynobj.h upstream/gold/dynobj.h
--- upstream.orig/gold/dynobj.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream/gold/dynobj.h	2011-05-25 23:41:13.203892583 +0200
@@ -647,7 +647,7 @@
   // Contents of --version-script, if passed, or NULL.
   const Version_script_info& version_script_;
   // Whether we need to insert a base version.  This is only used for
-  // shared libaries and is cleared when the base version is defined.
+  // shared libraries and is cleared when the base version is defined.
   bool needs_base_version_;
 };
 
diff -urN upstream.orig/gold/output.cc upstream/gold/output.cc
--- upstream.orig/gold/output.cc	2011-04-27 14:09:50.000000000 +0200
+++ upstream/gold/output.cc	2011-05-25 23:42:45.742491854 +0200
@@ -481,7 +481,7 @@
     }
 }
 
-// Write out the file header with appropriate size and endianess.
+// Write out the file header with appropriate size and endianness.
 
 template<int size, bool big_endian>
 void
diff -urN upstream.orig/include/coff/i860.h upstream/include/coff/i860.h
--- upstream.orig/include/coff/i860.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream/include/coff/i860.h	2011-05-25 23:39:44.345238311 +0200
@@ -58,7 +58,7 @@
 #define RELSZ 10
 
 /* The relocation directory entry types.
-     PAIR   : The low half that follows relates to the preceeding HIGH[ADJ].
+     PAIR   : The low half that follows relates to the preceding HIGH[ADJ].
      HIGH   : The high half of a 32-bit constant.
      LOWn   : The low half, insn bits 15..(n-1), 2^n-byte aligned. 
      SPLITn : The low half, insn bits 20..16 and 10..(n-1), 2^n-byte aligned. 
diff -urN upstream.orig/include/elf/common.h upstream/include/elf/common.h
--- upstream.orig/include/elf/common.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream/include/elf/common.h	2011-05-25 23:42:27.602766370 +0200
@@ -159,7 +159,7 @@
 #define EM_MMA		 54	/* Fujitsu Multimedia Accelerator */
 #define EM_PCP		 55	/* Siemens PCP */
 #define EM_NCPU		 56	/* Sony nCPU embedded RISC processor */
-#define EM_NDR1		 57	/* Denso NDR1 microprocesspr */
+#define EM_NDR1		 57	/* Denso NDR1 microprocessor */
 #define EM_STARCORE	 58	/* Motorola Star*Core processor */
 #define EM_ME16		 59	/* Toyota ME16 processor */
 #define EM_ST100	 60	/* STMicroelectronics ST100 processor */
diff -urN upstream.orig/include/elf/reloc-macros.h upstream/include/elf/reloc-macros.h
--- upstream.orig/include/elf/reloc-macros.h	2011-04-19 10:03:33.000000000 +0200
+++ upstream/include/elf/reloc-macros.h	2011-05-25 23:39:44.349238251 +0200
@@ -48,7 +48,7 @@
    set to the value of the whichever *_RELOC macro preceeds it plus
    one.  Therefore if you intend to use the symbol as a sentinel for
    the highest valid macro value you should make sure that the
-   preceeding *_RELOC macro is the highest valid number.  ie a
+   preceding *_RELOC macro is the highest valid number.  ie a
    declaration like this:
 
    	START_RELOC_NUMBERS (foo)
diff -urN upstream.orig/ld/ChangeLog-9899 upstream/ld/ChangeLog-9899
--- upstream.orig/ld/ChangeLog-9899	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/ChangeLog-9899	2011-05-25 23:41:56.799232599 +0200
@@ -1873,7 +1873,7 @@
 	section to avoid copying certain data on fork.  The linker used to
 	include this between __data_start__ and __data_end__, but that
 	breaks building the cygwin32 dll.  The fix is to rename the
-	section	".data_cygwin_nocopy" and explictly include it after
+	section	".data_cygwin_nocopy" and explicitly include it after
 	__data_end__.
 
 Wed Mar 18 09:42:24 1998  Nick Clifton  <nickc@cygnus.com>
diff -urN upstream.orig/ld/lexsup.c upstream/ld/lexsup.c
--- upstream.orig/ld/lexsup.c	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/lexsup.c	2011-05-25 23:41:13.223892279 +0200
@@ -454,7 +454,7 @@
     '\0', NULL, N_("Do not allow unresolved references in object files"),
     TWO_DASHES },
   { {"allow-shlib-undefined", no_argument, NULL, OPTION_ALLOW_SHLIB_UNDEFINED},
-    '\0', NULL, N_("Allow unresolved references in shared libaries"),
+    '\0', NULL, N_("Allow unresolved references in shared libraries"),
     TWO_DASHES },
   { {"no-allow-shlib-undefined", no_argument, NULL,
      OPTION_NO_ALLOW_SHLIB_UNDEFINED},
diff -urN upstream.orig/ld/po/bg.po upstream/ld/po/bg.po
--- upstream.orig/ld/po/bg.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/bg.po	2011-05-25 23:41:13.291891250 +0200
@@ -1718,7 +1718,7 @@
 msgstr "Непозволява несвързани отпратки при обектни файлове"
 
 #: lexsup.c:452
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Позволява несвързани отпратки при споделени библиотеки"
 
 #: lexsup.c:456
diff -urN upstream.orig/ld/po/da.po upstream/ld/po/da.po
--- upstream.orig/ld/po/da.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/da.po	2011-05-25 23:42:45.766491488 +0200
@@ -793,7 +793,7 @@
 
 #: ldlang.c:3018
 msgid "%P: warning: could not find any targets that match endianness requirement\n"
-msgstr "%P: advarsel: kunne ikke finde nogen m�l som matcher kravet p� endianess\n"
+msgstr "%P: advarsel: kunne ikke finde nogen m�l som matcher kravet p� endianness\n"
 
 #: ldlang.c:3032
 msgid "%P%F: target %s not found\n"
@@ -1779,7 +1779,7 @@
 
 #: lexsup.c:452
 #, fuzzy
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Tillad udefinerede symboler i delte objekter"
 
 #: lexsup.c:456
diff -urN upstream.orig/ld/po/es.po upstream/ld/po/es.po
--- upstream.orig/ld/po/es.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/es.po	2011-05-25 23:41:13.391889736 +0200
@@ -1721,7 +1721,7 @@
 msgstr "No permite referencias sin resolver en ficheros objeto"
 
 #: lexsup.c:452
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Permite referencias sin resolver en bibliotecas compartidas"
 
 #: lexsup.c:456
diff -urN upstream.orig/ld/po/fi.po upstream/ld/po/fi.po
--- upstream.orig/ld/po/fi.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/fi.po	2011-05-25 23:41:13.339890524 +0200
@@ -1729,7 +1729,7 @@
 msgstr "Älä salli ratkaisemattomia viitteitä objektitiedostoissa"
 
 #: lexsup.c:452
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Salli ratkaisemattomia viitteitä jaetuissa kirjastoissa"
 
 #: lexsup.c:456
diff -urN upstream.orig/ld/po/fr.po upstream/ld/po/fr.po
--- upstream.orig/ld/po/fr.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/fr.po	2011-05-25 23:41:13.267891613 +0200
@@ -1552,7 +1552,7 @@
 msgstr "Ne pas permettre les références indéfinis dans les objets partagés"
 
 #: lexsup.c:413
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Permettre les références non résolues dans les bibliothèques partagées"
 
 #: lexsup.c:417
diff -urN upstream.orig/ld/po/ga.po upstream/ld/po/ga.po
--- upstream.orig/ld/po/ga.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/ga.po	2011-05-25 23:41:13.431889130 +0200
@@ -1549,7 +1549,7 @@
 msgstr "N� ceadaigh tagairt� gan r�iteach i gcomhaid r�ada"
 
 #: lexsup.c:413
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Ceadaigh tagairt� gan r�iteach i gcomhleabharlanna"
 
 #: lexsup.c:417
diff -urN upstream.orig/ld/po/id.po upstream/ld/po/id.po
--- upstream.orig/ld/po/id.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/id.po	2011-05-25 23:41:13.411889433 +0200
@@ -1671,7 +1671,7 @@
 msgstr "Jangan perbolehkan referensi tidak terselesaikan dalam berkas objek"
 
 #: lexsup.c:424
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Ijinkan referensi tidak terselesaikan dalam perpustakaan terbagi"
 
 #: lexsup.c:428
diff -urN upstream.orig/ld/po/ja.po upstream/ld/po/ja.po
--- upstream.orig/ld/po/ja.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/ja.po	2011-05-25 23:41:13.499888101 +0200
@@ -1698,7 +1698,7 @@
 msgstr ""
 
 #: lexsup.c:452
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr ""
 
 #: lexsup.c:456
diff -urN upstream.orig/ld/po/ld.pot upstream/ld/po/ld.pot
--- upstream.orig/ld/po/ld.pot	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/ld.pot	2011-05-25 23:41:13.315890887 +0200
@@ -1722,7 +1722,7 @@
 msgstr ""
 
 #: lexsup.c:452
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr ""
 
 #: lexsup.c:456
diff -urN upstream.orig/ld/po/sv.po upstream/ld/po/sv.po
--- upstream.orig/ld/po/sv.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/sv.po	2011-05-25 23:42:45.786491188 +0200
@@ -607,7 +607,7 @@
 
 #: ldlang.c:1698
 msgid "%P: warning: could not find any targets that match endianness requirement\n"
-msgstr "%P: varning: kunde inte hitta n�gra m�l som matchar kravet p� endianess\n"
+msgstr "%P: varning: kunde inte hitta n�gra m�l som matchar kravet p� endianness\n"
 
 #: ldlang.c:1711
 msgid "%P%F: target %s not found\n"
diff -urN upstream.orig/ld/po/tr.po upstream/ld/po/tr.po
--- upstream.orig/ld/po/tr.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/tr.po	2011-05-25 23:41:13.451888827 +0200
@@ -1545,7 +1545,7 @@
 
 #: lexsup.c:391
 #, fuzzy
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Paylaşımlı kitaplıklara bağlanmaz"
 
 #: lexsup.c:395
diff -urN upstream.orig/ld/po/vi.po upstream/ld/po/vi.po
--- upstream.orig/ld/po/vi.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/vi.po	2011-05-25 23:41:13.475888464 +0200
@@ -1670,7 +1670,7 @@
 msgstr "Đừng cho phép tham chiệu chưa tháo gỡ trong tập tin đối tượng"
 
 #: lexsup.c:426
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Cho phép tham chiệu chưa tháo gỡ trong thư viện dùng chung"
 
 #: lexsup.c:430
diff -urN upstream.orig/ld/po/zh_CN.po upstream/ld/po/zh_CN.po
--- upstream.orig/ld/po/zh_CN.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/zh_CN.po	2011-05-25 23:41:13.359890220 +0200
@@ -1540,7 +1540,7 @@
 msgstr "不允许在目标文件中存在无法解析的引用"
 
 #: lexsup.c:391
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "允许在目标文件中存在无法解析的引用"
 
 #: lexsup.c:395
diff -urN upstream.orig/ld/po/zh_TW.po upstream/ld/po/zh_TW.po
--- upstream.orig/ld/po/zh_TW.po	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/po/zh_TW.po	2011-05-25 23:41:13.519887798 +0200
@@ -1496,7 +1496,7 @@
 msgstr "不允許在目的檔案中存在無法解析的參考"
 
 #: lexsup.c:392
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "允許在共享函式庫中存在無法解析的參考"
 
 #: lexsup.c:396
diff -urN upstream.orig/ld/scripttempl/epocpe.sc upstream/ld/scripttempl/epocpe.sc
--- upstream.orig/ld/scripttempl/epocpe.sc	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/scripttempl/epocpe.sc	2011-05-25 23:41:56.755233267 +0200
@@ -74,7 +74,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.orig/ld/scripttempl/i386beos.sc upstream/ld/scripttempl/i386beos.sc
--- upstream.orig/ld/scripttempl/i386beos.sc	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/scripttempl/i386beos.sc	2011-05-25 23:41:56.771233024 +0200
@@ -68,7 +68,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.orig/ld/scripttempl/mcorepe.sc upstream/ld/scripttempl/mcorepe.sc
--- upstream.orig/ld/scripttempl/mcorepe.sc	2011-04-19 10:03:33.000000000 +0200
+++ upstream/ld/scripttempl/mcorepe.sc	2011-05-25 23:41:56.775232964 +0200
@@ -74,7 +74,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.orig/ld/scripttempl/pep.sc upstream/ld/scripttempl/pep.sc
--- upstream.orig/ld/scripttempl/pep.sc	2011-05-08 01:44:05.000000000 +0200
+++ upstream/ld/scripttempl/pep.sc	2011-05-25 23:41:56.767233084 +0200
@@ -91,7 +91,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.orig/ld/scripttempl/pe.sc upstream/ld/scripttempl/pe.sc
--- upstream.orig/ld/scripttempl/pe.sc	2011-05-08 01:44:05.000000000 +0200
+++ upstream/ld/scripttempl/pe.sc	2011-05-25 23:41:56.763233145 +0200
@@ -90,7 +90,7 @@
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
diff -urN upstream.orig/opcodes/arm-dis.c upstream/opcodes/arm-dis.c
--- upstream.orig/opcodes/arm-dis.c	2011-04-21 12:39:41.000000000 +0200
+++ upstream/opcodes/arm-dis.c	2011-05-25 23:39:44.413237281 +0200
@@ -4702,7 +4702,7 @@
 	  if (!found)
 	    {
 	      /* No mapping symbol found at this address.  Look backwards
-		 for a preceeding one.  */
+		 for a preceding one.  */
 	      for (n = start - 1; n >= 0; n--)
 		{
 		  if (get_map_sym_type (info, n, &type))
@@ -4762,7 +4762,7 @@
 	  if (!found)
 	    {
 	      /* No mapping symbol found at this address.  Look backwards
-		 for a preceeding one.  */
+		 for a preceding one.  */
 	      for (n = start - 1; n >= 0; n--)
 		{
 		  if (get_sym_code_type (info, n, &type))
@@ -4984,5 +4984,5 @@
 	     regnames[i].description);
 
   fprintf (stream, "  force-thumb              Assume all insns are Thumb insns\n");
-  fprintf (stream, "  no-force-thumb           Examine preceeding label to determine an insn's type\n\n");
+  fprintf (stream, "  no-force-thumb           Examine preceding label to determine an insn's type\n\n");
 }

diff -urN upstream.orig/bfd/elf32-avr.c upstream/bfd/elf32-avr.c
--- upstream.orig/bfd/elf32-avr.c	2011-04-19 10:03:32.000000000 +0200
+++ upstream/bfd/elf32-avr.c	2011-05-25 23:39:42.797261761 +0200
@@ -2008,10 +2008,10 @@
                 if ((0x95 == next_insn_msb) && (0x08 == next_insn_lsb))
                   {
                     /* The next insn is a ret. We possibly could delete
-                       this ret. First we need to check for preceeding
+                       this ret. First we need to check for preceding
                        sbis/sbic/sbrs or cpse "skip" instructions.  */
 
-                    int there_is_preceeding_non_skip_insn = 1;
+                    int there_is_preceding_non_skip_insn = 1;
                     bfd_vma address_of_ret;
 
                     address_of_ret = dot + insn_size;
@@ -2023,51 +2023,51 @@
                       printf ("found jmp / ret sequence at address 0x%x\n",
                               (int) dot);
 
                     /* We have to make sure that there is a preceeding insn.  */
                     if (irel->r_offset >= 2)
                       {
-                        unsigned char preceeding_msb;
-                        unsigned char preceeding_lsb;
-                        preceeding_msb =
+                        unsigned char preceding_msb;
+                        unsigned char preceding_lsb;
+                        preceding_msb =
 			  bfd_get_8 (abfd, contents + irel->r_offset - 1);
-                        preceeding_lsb =
+                        preceding_lsb =
 			  bfd_get_8 (abfd, contents + irel->r_offset - 2);
 
                         /* sbic.  */
-                        if (0x99 == preceeding_msb)
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x99 == preceding_msb)
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbis.  */
-                        if (0x9b == preceeding_msb)
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x9b == preceding_msb)
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbrc */
-                        if ((0xfc == (preceeding_msb & 0xfe)
-			     && (0x00 == (preceeding_lsb & 0x08))))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if ((0xfc == (preceding_msb & 0xfe)
+			     && (0x00 == (preceding_lsb & 0x08))))
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbrs */
-                        if ((0xfe == (preceeding_msb & 0xfe)
-			     && (0x00 == (preceeding_lsb & 0x08))))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if ((0xfe == (preceding_msb & 0xfe)
+			     && (0x00 == (preceding_lsb & 0x08))))
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* cpse */
-                        if (0x10 == (preceeding_msb & 0xfc))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x10 == (preceding_msb & 0xfc))
+                          there_is_preceding_non_skip_insn = 0;
 
-                        if (there_is_preceeding_non_skip_insn == 0)
+                        if (there_is_preceding_non_skip_insn == 0)
                           if (debug_relax)
-                            printf ("preceeding skip insn prevents deletion of"
+                            printf ("preceding skip insn prevents deletion of"
                                     " ret insn at addr 0x%x in section %s\n",
                                     (int) dot + 2, sec->name);
                       }
                     else
                       {
                         /* There is no previous instruction.  */
-                        there_is_preceeding_non_skip_insn = 0;
+                        there_is_preceding_non_skip_insn = 0;
                       }
 
-                    if (there_is_preceeding_non_skip_insn)
+                    if (there_is_preceding_non_skip_insn)
                       {
                         /* We now only have to make sure that there is no
                            local label defined at the address of the ret
@@ -2023,51 +2023,51 @@
                               (int) dot);
 
-                    /* We have to make sure that there is a preceeding insn.  */
+                    /* We have to make sure that there is a preceding insn.  */
                     if (irel->r_offset >= 2)
                       {
diff -urN upstream.orig/libiberty/pex-win32.c upstream/libiberty/pex-win32.c
--- upstream.orig/libiberty/pex-win32.c	2011-04-21 12:39:41.000000000 +0200
+++ upstream/libiberty/pex-win32.c	2011-05-25 23:39:44.357238131 +0200
@@ -346,14 +346,14 @@
     {
       /* We quote every last argument.  This simplifies the problem;
 	 we need only escape embedded double-quotes and immediately
-	 preceeding backslash characters.  A sequence of backslach characters
+	 preceding backslash characters.  A sequence of backslach characters
 	 that is not follwed by a double quote character will not be
 	 escaped.  */
       for (j = 0; argv[i][j]; j++)
 	{
 	  if (argv[i][j] == '"')
 	    {
 	      /* Escape preceeding backslashes.  */
 	      for (k = j - 1; k >= 0 && argv[i][k] == '\\'; k--)
 		cmdline_len++;
 	      /* Escape the qote character.  */
@@ -346,14 +346,14 @@
 	  if (argv[i][j] == '"')
 	    {
-	      /* Escape preceeding backslashes.  */
+	      /* Escape preceding backslashes.  */
 	      for (k = j - 1; k >= 0 && argv[i][k] == '\\'; k--)
 		cmdline_len++;